@@ -1376,13 +1376,14 @@ class NDArray(HasTraits):
         """
         True if the `data` array is dimensionless - Readonly property (bool).
 
-        Notes
-        -----
-        `Dimensionless` is different of `unitless` which means no unit.
-
         See Also
         --------
-        unitless, has_units
+        unitless : True if data has no units.
+        has_units : True if data has units.
+
+         Notes
+        -----
+        `Dimensionless` is different of `unitless` which means no unit.
         """
         if self.unitless:
             return False
@@ -1546,7 +1547,8 @@ class NDArray(HasTraits):
     @property
     def has_data(self):
         """
-        True if the `data` array is not empty and size > 0 (Bool).
+        True if the `data` array is not empty and size > 0.
+
         (Readonly property).
         """
         if (self.data is None) or (self.data.size == 0):
@@ -1570,7 +1572,8 @@ class NDArray(HasTraits):
 
         See Also
         --------
-        unitless, dimensionless
+        unitless : True if the data has no unit.
+        dimensionless : True if the data have dimensionless units.
         """
         if self._units is not None:
             return True
@@ -1665,8 +1668,9 @@ class NDArray(HasTraits):
     @property
     def is_empty(self):
         """
-        True if the `data` array is empty or size=0, and if no label are present
-        - Readonly property (bool).
+        True if the `data` array is empty or size=0, and if no label are present.
+
+        Readonly property (bool).
         """
         if ((self._data is None) or (self._data.size == 0)) and not self.is_labeled:
             return True
@@ -1738,22 +1742,6 @@ class NDArray(HasTraits):
             return False
         return True
 
-    # ..........................................................................
-    @property
-    def itemsize(self):
-        """
-        Data type size (int).
-        """
-        if self.data is None:
-            return None
-
-        return self.data.dtype.itemsize
-
-    # ..........................................................................
-    @property
-    def iterdims(self):
-        return list(range(self.ndim))
-
     # ..........................................................................
     def ito(self, other, force=False):
         """
@@ -2319,20 +2307,23 @@ class NDArray(HasTraits):
                 # particular case of dimensionless units: absorbance and transmittance
                 else:
 
-                    if oldunits in [ur.transmittance, ur.absolute_transmittance]:
-                        if units == ur.absorbance:
+                    if f"{oldunits:P}" in ["transmittance", "absolute_transmittance"]:
+                        if f"{units:P}" == "absorbance":
                             udata = (new.data * new.units).to(units)
                             new._data = -np.log10(udata.m)
                             new._units = units
                             new._title = "absorbance"
 
-                        elif units in [ur.transmittance, ur.absolute_transmittance]:
+                        elif f"{units:P}" in [
+                            "transmittance",
+                            "absolute_transmittance",
+                        ]:
                             new._data = (new.data * new.units).to(units)
                             new._units = units
-                            new._title = "absorbance"
+                            new._title = "transmittance"
 
-                    elif oldunits == ur.absorbance:
-                        if units in [ur.transmittance, ur.absolute_transmittance]:
+                    elif f"{oldunits:P}" == "absorbance":
+                        if f"{units:P}" in ["transmittance", "absolute_transmittance"]:
                             scale = Quantity(1.0, self._units).to(units).magnitude
                             new._data = 10.0 ** -new.data * scale
                             new._units = units
