@@ -1,13 +1,11 @@
 # -*- coding: utf-8 -*-
-#
+
 # ======================================================================================================================
-# Copyright (©) 2015-2020 LCS
-# Laboratoire Catalyse et Spectrochimie, Caen, France.
-# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
-# See full LICENSE agreement in the root directory
+#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
 # ======================================================================================================================
 
-__all__ = ['savgol_filter', 'detrend']
+__all__ = ["savgol_filter", "detrend"]
 
 __dataset_methods__ = __all__
 
@@ -22,9 +20,19 @@ import scipy.signal
 # argrelmax(data[, axis, order, mode]) 	Calculate the relative maxima of data.
 # argrelextrema(data, comparator[, axis, ...]) 	Calculate the relative extrema of data.
 
-def savgol_filter(dataset, window_length=5, polyorder=0, deriv=0, delta=1.0, dim='x', mode='interp', cval=0.0):
+
+def savgol_filter(
+    dataset,
+    window_length=5,
+    polyorder=0,
+    deriv=0,
+    delta=1.0,
+    mode="interp",
+    cval=0.0,
+    **kwargs,
+):
     """
-    Apply a Savitzky-Golay filter to a NDDataset()
+    Apply a Savitzky-Golay filter to a NDDataset.
 
     Wrapper of scpy.signal.savgol(). If dataset has dimension greater than 1,
     dim determines the axis along which the filter is applied.
@@ -43,8 +51,6 @@ def savgol_filter(dataset, window_length=5, polyorder=0, deriv=0, delta=1.0, dim
         The default is 0, which means to filter the data without differentiating.
     delta : float, optional
         The spacing of the samples to which the filter will be applied. This is only used if deriv > 0. Default is 1.0.
-    dim : str. Optional, default='x'.
-        Along which axis to perform the alignment.
     mode : str, optional
         Must be ‘mirror’, ‘constant’, ‘nearest’, ‘wrap’ or ‘interp’. This determines the type of extension to use for
         the padded signal to which the filter is applied. When mode is ‘constant’, the padding value is given by cval.
@@ -54,12 +60,22 @@ def savgol_filter(dataset, window_length=5, polyorder=0, deriv=0, delta=1.0, dim
         last window_length // 2 output values.
     cval : scalar, optional
         Value to fill past the edges of the input if mode is ‘constant’. Default is 0.0.
+    **kwargs
+        Optional keyword parameters (see Other Parameters).
 
     Returns
     -------
     NDDataset: same shape as x. data units are removed when deriv > 1
         The filtered data.
 
+    Other Parameters
+    ----------------
+    dim : str or int, optional, default='x'.
+        Specify on which dimension to apply this method. If `dim` is specified as an integer it is equivalent
+        to the usual `axis` numpy parameter.
+    inplace : bool, optional, default=False.
+        True if we make the transform inplace.  If False, the function return a new object
+
     Notes
     -----
     Even spacing of the axis coordinates is NOT checked. Be aware that Savitzky-Golay algorithm
@@ -87,38 +103,62 @@ def savgol_filter(dataset, window_length=5, polyorder=0, deriv=0, delta=1.0, dim
     'constant' | 0  0  0 | 1  2  3  4  5  6  7  8 | 0  0  0
     'wrap'     | 6  7  8 | 1  2  3  4  5  6  7  8 | 1  2  3
 
+    See Also
+    ---------
+    smooth : Smooth the data using a window with requested size.
+
+    Examples
+    --------
+
+    >>> dataset = scp.read('irdata/nh4y-activation.spg')
+    >>> dataset.savgol_filter(window_length=5, polyorder=0)
+    NDDataset: [float64] a.u. (shape: (y:55, x:5549))
     """
 
-    if dim == 'x':
-        axis = -1
-    if dim == 'y':
-        axis = -2
-    if dim == 'z':
-        axis = -3
-
-    data = scipy.signal.savgol_filter(dataset.data, window_length, polyorder,
-                                      deriv, delta, axis, mode, cval)
-
-    out = dataset.copy()
-    if deriv == 0:
-        out.data = data * dataset.units
+    if not kwargs.pop("inplace", False):
+        # default
+        new = dataset.copy()
     else:
-        out.data = data
-        if dataset.coord([dim]).reversed:
-            out.data = out.data * (-1) ** deriv
-    return out
+        new = dataset
+
+    is_ndarray = False
+    axis = kwargs.pop("dim", kwargs.pop("axis", -1))
+    if hasattr(new, "get_axis"):
+        axis, dim = new.get_axis(axis, negative_axis=True)
+        data = new.data
+    else:
+        is_ndarray = True
+        data = new
+
+    data = scipy.signal.savgol_filter(
+        data, window_length, polyorder, deriv, delta, axis, mode, cval
+    )
+
+    if not is_ndarray:
+        if deriv != 0 and dataset.coord(dim).reversed:
+            data = data * (-1) ** deriv
+        new.data = data
+    else:
+        new = data
+
+    if not is_ndarray:
+        new.history = (
+            f"savgol_filter applied (window_length={window_length}, polyorder={polyorder}, "
+            f"deriv={deriv}, delta={delta}, mode={mode}, cval={cval}"
+        )
+    return new
 
 
-def detrend(dataset, dim='x', type='linear', bp=0, overwrite_data=False):
+def detrend(dataset, type="linear", bp=0, **kwargs):
     """
-    Wrapper of scpy.signal.detrend(). Remove linear trend along dim from dataset.
+    Remove linear trend along dim from dataset.
+
+    Wrapper of scpy.signal.detrend().
 
     Parameters
     ----------
     dataset :  |NDDataset|
-        The input data
-    dim : str, optional, default='x'
-        The dimension, along which to detrend the data. By default this is the 'x' dimension.
+        The input data.
     type : str among ['linear', 'constant'}, optional, default='linear'
         The type of detrending. If ``type == 'linear'`` (default),
         the result of a linear least-squares fit to `data` is subtracted from `data`.
@@ -127,22 +167,55 @@ def detrend(dataset, dim='x', type='linear', bp=0, overwrite_data=False):
         A sequence of break points. If given, an individual linear fit is
         performed for each part of `data` between two break points.
         Break points are specified as indices into `data`.
-    overwrite_data : bool, optional, Default=False
-        If True, perform in place detrending and avoid a copy.
+    **kwargs
+        Optional keyword parameters (see Other Parameters).
 
     Returns
     -------
-    ret : NDDataset
-        The detrended input data.
-    """
-    if dim == 'x':
-        axis = -1
-    if dim == 'y':
-        axis = -2
-    if dim == 'z':
-        axis = -3
+    detrended
+        The detrended |NDDataset|.
 
-    data = scipy.signal.detrend(dataset.data, axis=axis, type=type, bp=bp)
-    out = dataset.copy()
-    out.data = data
-    return out
+    Other Parameters
+    ----------------
+    dim : str or int, optional, default='x'.
+        Specify on which dimension to apply this method. If `dim` is specified as an integer it is equivalent
+        to the usual `axis` numpy parameter.
+    inplace : bool, optional, default=False.
+        True if we make the transform inplace.  If False, the function return a new object
+
+    See Also
+    --------
+    BaselineCorrection : Manual baseline correction.
+    abs : Automatic baseline correction.
+    autosub : Subtraction of reference.
+
+    Examples
+    --------
+
+    >>> dataset = scp.read("irdata/nh4y-activation.spg")
+    >>> dataset.detrend(type='constant')
+    NDDataset: [float64] a.u. (shape: (y:55, x:5549))
+    """
+    if not kwargs.pop("inplace", False):
+        # default
+        new = dataset.copy()
+    else:
+        new = dataset
+
+    is_ndarray = False
+    axis = kwargs.pop("dim", kwargs.pop("axis", -1))
+    if hasattr(new, "get_axis"):
+        axis, dim = new.get_axis(axis, negative_axis=True)
+        data = new.data
+    else:
+        is_ndarray = True
+        data = new
+
+    data = scipy.signal.detrend(data, axis=axis, type=type, bp=bp)
+
+    if is_ndarray:
+        return data
+
+    new.data = data
+
+    return new
