@@ -8,9 +8,12 @@
 """
 This module define a generic class to import directories, files and contents.
 """
-__all__ = ["read", "read_dir"]
+__all__ = ["read", "read_dir", "read_remote"]
 __dataset_methods__ = __all__
 
+import requests
+import yaml
+
 from warnings import warn
 from datetime import datetime, timezone
 from traitlets import HasTraits, List, Dict, Type, Unicode
@@ -121,7 +124,7 @@ class Importer(HasTraits):
             elif key and key[1:] not in list(zip(*FILETYPES))[0] + list(zip(*ALIAS))[0]:
                 raise TypeError(f"Filetype `{key}` is unknown in spectrochempy")
             else:
-                # here files are read from the disk using filenames
+                # here files are read / or remotely from the disk using filenames
                 self._switch_protocol(key, self.files, **kwargs)
 
         # now we will reset preference for this newly loaded datasets
@@ -193,35 +196,43 @@ class Importer(HasTraits):
         datasets = []
         for filename in files[key]:
             filename = pathclean(filename)
-            # try:
             read_ = getattr(self, f"_read_{key[1:]}")
-            # except AttributeError:
-            #     warning_(
-            #         f"a file with extension {key} was found in this directory but will be ignored"
-            #     )
-            #
             try:
                 res = read_(self.objtype(), filename, **kwargs)
                 # sometimes read_ can return None (e.g. non labspec text file)
-                if res is not None:
-                    if not isinstance(res, list):
-                        datasets.append(res)
-                    else:
-                        datasets.extend(res)
+            except FileNotFoundError as e:
+                # try to get the file from github
+                kwargs["read_method"] = read_
+                try:
+                    res = _read_remote(self.objtype(), filename, **kwargs)
 
-            except FileNotFoundError:
-                raise
+                except OSError:
+                    raise e
+
+                except IOError as e:
+                    warning_(str(e))
+                    res = None
+
+                except NotImplementedError as e:
+                    warning_(str(e))
+                    res = None
+
+                except Exception:
+                    raise e
 
             except IOError as e:
                 warning_(str(e))
+                res = None
 
             except NotImplementedError as e:
                 warning_(str(e))
+                res = None
 
-            # except Exception as e:
-            #     warning_(
-            #         f"The file `{filename}` has a known extension but it could not be read. It is ignored!"
-            #     )
+            if res is not None:
+                if not isinstance(res, list):
+                    datasets.append(res)
+                else:
+                    datasets.extend(res)
 
         if len(datasets) > 1:
             datasets = self._do_merge(datasets, **kwargs)
@@ -248,7 +259,7 @@ class Importer(HasTraits):
         if merged:
             # Try to stack the dataset into a single one
             try:
-                dataset = self.objtype.stack(datasets)
+                dataset = self.objtype.concatenate(datasets, axis=0)
                 if dataset.coordset is not None and kwargs.pop("sortbydate", True):
                     dataset.sort(dim="y", inplace=True)
                     dataset.history = (
@@ -263,8 +274,8 @@ class Importer(HasTraits):
 
 
 # ..............................................................................
-def importermethod(func):
-    # Decorateur
+def _importer_method(func):
+    # Decorator to define a given read function as belonging to Importer
     setattr(Importer, func.__name__, staticmethod(func))
     return func
 
@@ -484,12 +495,167 @@ def read_dir(directory=None, **kwargs):
     return importer(directory, **kwargs)
 
 
+def read_remote(file_or_dir, **kwargs):
+    """
+    Download and read files or an entire directory on github spectrochempy_data
+    repository.
+
+    This is done only if the data are not yet downloaded and present in the DATADIR
+    directory.
+
+    Parameters
+    ----------
+    file_or_dir : str or pathlib
+        Folder where are located the files to read
+        (it should be written as if it was locally downloaded already).
+    **kwargs : optional keywords parameters
+        See Other Parameters.
+
+    Other Parameters
+    ----------------
+    merge : bool, optional, default: False
+        By default files read are noot merged
+    replace_existing: bool, optional, default: False
+        By default, existing files are not replaced so not downloaded.
+    download_only: bool, optional, default: False
+        If True, only downloading and saving of the files is performed, with no
+        attempt to read their content.
+
+    Returns
+    --------
+    dataset(s)
+        |NDDataset| or list of |NDDataset|.
+
+    See Also
+    --------
+    read_topspin : Read TopSpin Bruker NMR spectra.
+    read_omnic : Read Omnic spectra.
+    read_opus : Read OPUS spectra.
+    read_spg : Read Omnic \*.spg grouped spectra.
+    read_spa : Read Omnic \*.spa single spectra.
+    read_srs : Read Omnic series.
+    read_csv : Read CSV files.
+    read_zip : Read Zip files.
+    read_matlab : Read Matlab files.
+
+    Examples
+    --------
+
+    >>> A = scp.read_remote('irdata/subdir')
+    """
+    kwargs["remote"] = True
+    if "merge" not in kwargs:
+        kwargs["merge"] = False  # by default, no attempt to merge
+    if "replace_existing" not in kwargs:
+        kwargs["replace_existing"] = False  # by default we download only if needed.
+    importer = Importer()
+    return importer(file_or_dir, **kwargs)
+
+
+def _get_url_content_and_save(url, dst, replace):
+
+    if not replace and dst.exists():
+        return
+
+    try:
+        r = requests.get(url, allow_redirects=True)
+
+        # write downloaded file
+        if not dst.parent.exists():
+            # create the eventually missing subdirectory
+            dst.parent.mkdir(parents=True, exist_ok=True)
+        dst.write_bytes(r.content)
+        print(f"{dst.name} has been downloaded and written in {dst.parent}")
+
+    except OSError:
+        raise FileNotFoundError(f"Not found locally or on github (url:{url}")
+
+
+def _download_from_url(url, dst, replace=False):
+    # ##
+    # ##    Do not forget to change the fork in the following url
+    # ##
+    if not str(url).startswith("https://"):
+        # try on github
+        url = (
+            f"https://github.com/spectrochempy/spectrochempy_data/raw/master/"
+            f"testdata/{url}"
+        )
+    # first determine if it is a directory
+    r = requests.get(url + "/__index__", allow_redirects=True)
+    index = None
+    if r.status_code == 200:
+        index = yaml.load(r.content, Loader=yaml.CLoader)
+
+    if index is None:
+        _get_url_content_and_save(url, dst, replace)
+
+    else:
+        for filename in index["files"]:
+            _get_url_content_and_save(f"{url}/{filename}", dst / filename, replace)
+        for folder in index["folders"]:
+            _download_from_url(f"{url}/{folder}", dst / folder)
+
+
+def _is_relative_to(path, base):
+    # try to emulate the pathlib is_relative_to method which does not work on python
+    # 3.7 (needed for Colab!)
+    # TODO: replace if Colab is (unlikely) updated to a compatible version
+    pparts = path.parts
+    bparts = base.parts
+    if bparts[-1] in pparts:
+        idx = pparts.index(bparts[-1])
+        pparts_base = pparts[: idx + 1]
+        return pparts_base == bparts
+    return False
+
+
+def _relative_to(path, base):
+    pparts = path.parts
+    bparts = base.parts
+    if bparts[-1] in pparts:
+        idx = pparts.index(bparts[-1])
+        return pathclean("/".join(pparts[idx + 1 :]))
+    raise ValueError(
+        f"'{path}' is not in the subpath of '{base}' OR one path is "
+        f"relative and the other absolute."
+    )
+
+
+@_importer_method
+def _read_remote(*args, **kwargs):
+    from spectrochempy.core import preferences as prefs
+
+    datadir = prefs.datadir
+
+    dataset, path = args
+    # path of the required files
+    path = pathclean(path)
+
+    if _is_relative_to(path, datadir):
+        # try to make it relative for remote downloading
+        relative_path = _relative_to(path, datadir)
+    else:
+        # assume it is already relative
+        relative_path = path
+
+    # in principle the data came from github. Try to download it
+
+    replace = kwargs.pop("replace_existing", False)
+    dst = datadir / relative_path
+    _download_from_url(relative_path, dst, replace)
+
+    if not kwargs.pop("download_only", False):
+        read_method = kwargs.pop("read_method", read)
+        return read_method(dataset, dst, **kwargs)
+
+
 # ======================================================================================================================
 # Private functions
 # ======================================================================================================================
 
 
-@importermethod
+@_importer_method
 def _read_dir(*args, **kwargs):
     _, directory = args
     directory = get_directory_name(directory)
@@ -507,18 +673,20 @@ def _read_dir(*args, **kwargs):
 
 
 # ..............................................................................
-@importermethod
+@_importer_method
 def _read_scp(*args, **kwargs):
     dataset, filename = args
     return dataset.load(filename, **kwargs)
 
 
 # ..............................................................................
-@importermethod
+@_importer_method
 def _read_(*args, **kwargs):
     dataset, filename = args
 
-    if not filename or filename.is_dir():
+    if kwargs.pop("remote", False):
+        return Importer._read_remote(*args, **kwargs)
+    elif not filename or filename.is_dir():
         return Importer._read_dir(*args, **kwargs)
 
     # protocol = kwargs.get("protocol", None)
