@@ -21,13 +21,16 @@ import numpy as np
 from spectrochempy.core import info_
 from spectrochempy.core.dataset.coord import Coord, LinearCoord
 from spectrochempy.core.dataset.nddataset import NDDataset
-from spectrochempy.core.readers.importer import importermethod, Importer
+from spectrochempy.core.readers.importer import (
+    _importer_method,
+    Importer,
+)
 from spectrochempy.core.units import Quantity
 
 
-# ======================================================================================================================
+# ======================================================================================
 # Public functions
-# ======================================================================================================================
+# ======================================================================================
 def read_omnic(*paths, **kwargs):
     """
     Open a Thermo Nicolet OMNIC file.
@@ -109,13 +112,13 @@ def read_omnic(*paths, **kwargs):
     --------
     read : Generic read method.
     read_dir : Read a set of data from a directory.
-    read_spg : Read Omnic files *.spg.
-    read_spa : Read Omnic files *.spa.
-    read_srs : Read Omnic files *.srs.
+    read_spg : Read Omnic files .spg.
+    read_spa : Read Omnic files .spa.
+    read_srs : Read Omnic files .srs.
     read_opus : Read Bruker OPUS files.
     read_topspin : Read TopSpin NMR files.
-    read_csv : Read *.csv.
-    read_matlab : Read MATLAB files *.mat.
+    read_csv : Read .csv.
+    read_matlab : Read MATLAB files .mat.
     read_zip : Read zipped group of files.
 
     Examples
@@ -495,7 +498,7 @@ def read_srs(*paths, **kwargs):
 
     Examples
     ---------
-    >>> scp.read_srs('irdata/omnic series/rapid_scan_reprocessed.srs')
+    >>> scp.read_srs('irdata/omnic_series/rapid_scan_reprocessed.srs')
     NDDataset: [float64] a.u. (shape: (y:643, x:3734))
     """
 
@@ -505,12 +508,12 @@ def read_srs(*paths, **kwargs):
     return importer(*paths, **kwargs)
 
 
-# ======================================================================================================================
+# ======================================================================================
 # Private functions
-# ======================================================================================================================
+# ======================================================================================
 
-# ..............................................................................
-@importermethod
+# ......................................................................................
+@_importer_method
 def _read_spg(*args, **kwargs):
     # read spg file
 
@@ -742,7 +745,7 @@ def _read_spg(*args, **kwargs):
 
 
 # ..............................................................................
-@importermethod
+@_importer_method
 def _read_spa(*args, **kwargs):
     dataset, filename = args
     content = kwargs.get("content", False)
@@ -925,7 +928,7 @@ def _read_spa(*args, **kwargs):
 
 
 # ..............................................................................
-@importermethod
+@_importer_method
 def _read_srs(*args, **kwargs):
     dataset, filename = args
     frombytes = kwargs.get("frombytes", False)
